@@ -1,13 +1,15 @@
+import collections
 import hashlib
 import secrets
 import string
 from datetime import timezone, datetime
 
 import requests
+from typing import Tuple
 
 
 class BaseAPI:
-    def __init__(self, api_key_id: int, api_key: str, fqdn: str, api_name: str, timeout: tuple[int, int]) -> None:
+    def __init__(self, api_key_id: int, api_key: str, fqdn: str, api_name: str, timeout: Tuple[int, int]) -> None:
         self._api_key_id = api_key_id
         self._api_key = api_key
         self._fqdn = fqdn
@@ -34,9 +36,11 @@ class BaseAPI:
               call_name: str,
               method: str = "post",
               params: dict = None,
-              json_value: object = None) -> requests.Response:
+              json_value: object = None,
+              header_params: dict = {}) -> requests.Response:
         url = self._get_url(call_name)
         headers = self._get_headers()
+        self.extend(headers, header_params)
 
         return self._execute_call(url=url,
                                   method=method,
@@ -59,4 +63,18 @@ class BaseAPI:
             response = requests.put(url, headers=headers, json=json_value, timeout=self._requests_timeout)
         elif method == 'delete':
             response = requests.delete(url, headers=headers, timeout=self._requests_timeout)
+        response.raise_for_status()
         return response
+
+    @staticmethod
+    def extend(*args):
+        if args is not None:
+            result = None
+            if type(args[0]) is collections.OrderedDict:
+                result = collections.OrderedDict()
+            else:
+                result = {}
+            for arg in args:
+                result.update(arg)
+            return result
+        return {}
